@@ -18,8 +18,8 @@
  *   along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef PLASMAVAULT_KDED_ENGINE_SINGLETON_H
-#define PLASMAVAULT_KDED_ENGINE_SINGLETON_H
+#ifndef PLASMAVAULT_KDED_ENGINE_SINGLETON_P_H
+#define PLASMAVAULT_KDED_ENGINE_SINGLETON_P_H
 
 #include <mutex>
 #include <memory>
